import { ReactElement } from 'react';

interface I_twemoji {
    base: string;
    parse: (str: string, options: {}) => string;
    replace: (text: string, callback: (tag: string) => {}) => string;
    convert: {
        toCodePoint: (tag: string) => string;
    };
}
interface I_initTwemoji {
    twemoji: I_twemoji;
    baseUrl: string;
}
interface I_emoji {
    name?: string;
    id?: number;
}
interface I_emoji_size {
    width?: number;
    height?: number;
}

/**
 * @description 设置emoji源
 * @param {string} origin
 */
declare function setEmojiOrigin(origin: string): void;
/**
 * @description 获取自定义emoji url
 * @param {number} [id]
 * @returns {*}  {string}
 */
declare function getCustomEmojiUrl(id?: number): string;
/**
 * @description 自定义emoji转text
 * @param {I_emoji} [emoji={}]
 * @returns {*}  {string}
 */
declare function customEmojiToText(emoji?: I_emoji): string;
/**
 * @description 自定义emoji转html
 * @param {I_emoji} emoji
 * @param {I_emoji_size} size
 * @returns {*}
 */
declare function customEmojiToHTML(emoji: I_emoji, size: I_emoji_size): string;
declare const customEmojiReg: RegExp;
/**
 * @description html编码 不转义&nbsp;其他转义
 * @param {string} [str='']
 * @returns {*}  {string}
 */
declare function htmlEncode(str?: string): string;
/**
 * @description html 解码
 * @param {string} [str='']
 * @returns {*} {string}
 */
declare function htmlDecode(str?: string): string;
/**
 * @description 将所有html进行编码
 * @export
 * @param {string} [htmlStr=''] html string
 * @returns {*}  {string}
 */
declare function encodeLocalHtml(htmlStr?: string): string;
/**
 * @description 初始化设置内部emoji方法使用的前置twemoji对象
 * @param {I_twemoji} twemoji
 */
declare function initTwemoji({ twemoji, baseUrl }: I_initTwemoji): void;
/**
 * @description 解析emoji
 * @param {string} str
 * @returns {*}  {string}
 */
declare function parseEmoji(str: string): string;
/**
 * @description 解析emoji（解码后解析）
 * @param {string} [str='']
 * @param {boolean} [encodenbsp=true]
 * @returns {*}
 */
declare function printEmoji(str?: string, encodenbsp?: boolean): string;
/**
 * @description 将emoji解析成 react组件
 * @param {string} [str='']
 * @param {boolean} [encodenbsp=true]
 * @returns {*}  {ReactElement[]}
 */
declare function printReactEmoji(str?: string, encodenbsp?: boolean): ReactElement[];
/**
 * @description 获取emoji url
 * @param {string} tag
 * @returns {*}  {string}
 */
declare function getEmojiUrl(tag: string): string;
/**
 * @description 解析自定义emoji
 * @param {string} [text='']
 * @returns {*}
 */
declare function parseCustomEmoji(text?: string): {
    id: string;
    name: string;
} | null;
/**
 * @description 遍历数组 当数字项为字符串时调用回调函数处理
 * @param {any[]} objArr
 * @param {(param: any) => any} fun
 * @returns {*}  {any[]}
 */
declare function splitHelper(objArr: any[], fun: (param: any) => any): any[];
/**
 * @description
 * @param {string} [text='']
 * @param {(tag: string) => {}} callback
 * @returns {*}  {any[]}
 */
declare function splitEmoji(text: string | undefined, callback: (tag: string) => {}): any[];
/**
 * @description
 * @param {string} str
 * @param {RegExp} reg
 * @param {(...args: any) => {}} callback
 * @returns {*}  {any[]}
 */
declare function splitReg(str: string, reg: RegExp, callback: (...args: any) => {}): any[];

export { customEmojiReg, customEmojiToHTML, customEmojiToText, encodeLocalHtml, getCustomEmojiUrl, getEmojiUrl, htmlDecode, htmlEncode, initTwemoji, parseCustomEmoji, parseEmoji, printEmoji, printReactEmoji, setEmojiOrigin, splitEmoji, splitHelper, splitReg };
