// src/emoji/index.ts
import ReactHtmlParser from "react-html-parser";
var _twemoji = {
  base: "",
  parse: () => {
    console.log("\u8FD9\u662F\u9ED8\u8BA4\u7684parse \u8BF7\u5148\u8C03\u7528initTwemoji\u51FD\u6570");
    return "";
  },
  convert: {
    toCodePoint: () => {
      console.log("\u8FD9\u662F\u9ED8\u8BA4\u7684toCodePoint \u8BF7\u5148\u8C03\u7528initTwemoji\u51FD\u6570");
      return "";
    }
  },
  replace: () => {
    console.log("\u8FD9\u662F\u9ED8\u8BA4\u7684replace \u8BF7\u5148\u8C03\u7528initTwemoji\u51FD\u6570");
    return "";
  }
};
var _baseUrl = "";
var emojiOrigin = "https://img.kookapp.cn";
function setEmojiOrigin(origin) {
  emojiOrigin = origin;
}
function getCustomEmojiUrl(id) {
  return `${emojiOrigin}/emojis/${id}.png`;
}
function customEmojiToText(emoji = {}) {
  return `[:${emoji.name}:${emoji.id}]`;
}
function customEmojiToHTML(emoji, size) {
  let sizeStr = size ? `style="${size.width ? `width:${size.width}px` : ""};height:${size.height}px;"` : "";
  return `<img class="emoji custom" aria-label="${customEmojiToText(
    emoji
  )}" alt="${customEmojiToText(emoji)}" src="${getCustomEmojiUrl(
    emoji.id
  )}" ${sizeStr} />`;
}
var customEmojiReg = /\[:([^:]{2,36}):([\d/a-zA-Z]+)\]/g;
function htmlEncode(str = "") {
  let temp = "";
  if (str.length === 0) {
    return "";
  }
  temp = str.replace(/</g, "&lt;").replace(/>/g, "&gt;").replace(/\'/g, "&#39;").replace(/\"/g, "&quot;").replace(/&#8238;/g, "").replace(/&#8207;/g, "");
  return temp;
}
function htmlDecode(str = "") {
  let temp = "";
  if (str.length == 0) {
    return "";
  }
  temp = str.replace(/&amp;/g, "&").replace(/&lt;/g, "<").replace(/&gt;/g, ">").replace(/&#39;/g, "'").replace(/&#039;/g, "'").replace(/&quot;/g, '"');
  return temp;
}
function encodeLocalHtml(htmlStr = "") {
  return htmlStr.replace(
    /[<>&"]/g,
    (c) => ({
      "<": "&lt;",
      ">": "&gt;",
      "&": "&amp;",
      '"': "&quot;",
      "'": "&#39;",
      "&#8238;": "",
      "&#8207;": ""
    })[c]
  );
}
function initTwemoji({ twemoji, baseUrl }) {
  _baseUrl = baseUrl;
  twemoji.base = baseUrl;
  const oldParse = twemoji.parse;
  twemoji.parse = function(str, options) {
    str = str.replace(
      /\uD83D\uDC41\uFE0F\u200D\uD83D\uDDE8\uFE0F/g,
      "\u{1F441}\u200D\u{1F5E8}"
    );
    return oldParse.call(twemoji, str, options);
  };
  _twemoji = twemoji;
}
function parseEmoji(str) {
  const temp = _twemoji.parse(str, {
    folder: "svg",
    ext: ".svg"
  });
  return temp;
}
function printEmoji(str = "", encodenbsp = true) {
  let temp = "";
  if (encodenbsp) {
    temp = encodeLocalHtml(str);
  } else {
    temp = htmlEncode(str);
  }
  temp = _twemoji.parse(str, {
    folder: "svg",
    ext: ".svg"
  });
  return temp;
}
function printReactEmoji(str = "", encodenbsp = true) {
  str = str || "";
  if (encodenbsp) {
    str = encodeLocalHtml(str);
  } else {
    str = htmlEncode(str);
  }
  str = _twemoji.parse(str, {
    folder: "svg",
    ext: ".svg"
  });
  return ReactHtmlParser(str);
}
function getEmojiUrl(tag) {
  tag = tag.indexOf("\u200D") < 0 ? tag.replace(/\uFE0F/g, "") : tag;
  const emojiId = _twemoji.convert.toCodePoint(tag);
  return `${_baseUrl}svg/${emojiId}.svg`;
}
function parseCustomEmoji(text = "") {
  const match = customEmojiReg.exec(text);
  customEmojiReg.lastIndex = 0;
  if (!match) {
    return null;
  }
  return {
    id: match[2],
    name: match[1]
  };
}
function splitHelper(objArr, fun) {
  const result = [];
  objArr.map((item) => {
    if (typeof item !== "string") {
      result.push(item);
      return;
    }
    result.push(...fun(item));
  });
  return result;
}
var placeholder = "[!@#$%~emoji]";
function splitEmoji(text = "", callback) {
  const emojiList = [];
  const temp = _twemoji.replace(text, (tag) => {
    if (typeof callback == "function") {
      emojiList.push(callback(tag));
    } else {
      const emoji = {
        type: "emoji",
        tag
      };
      emojiList.push(emoji);
    }
    return placeholder;
  });
  const arr = temp.split(placeholder);
  return acrossMerge(arr, emojiList);
}
function acrossMerge(strArr, objArr) {
  const result = [];
  const tempArr = [...objArr];
  strArr.forEach((item) => {
    result.push(item);
    const shiftItem = tempArr.shift();
    if (shiftItem) {
      result.push(shiftItem);
    }
  });
  return result;
}
function splitReg(str, reg, callback) {
  const objArr = [];
  str = str.replace(reg, (...args) => {
    let obj = callback(...args);
    objArr.push(obj);
    return placeholder;
  });
  let fragment = str.split(placeholder);
  return acrossMerge(fragment, objArr);
}
export {
  customEmojiReg,
  customEmojiToHTML,
  customEmojiToText,
  encodeLocalHtml,
  getCustomEmojiUrl,
  getEmojiUrl,
  htmlDecode,
  htmlEncode,
  initTwemoji,
  parseCustomEmoji,
  parseEmoji,
  printEmoji,
  printReactEmoji,
  setEmojiOrigin,
  splitEmoji,
  splitHelper,
  splitReg
};
